@@ -18,7 +18,7 @@
 
 #define QT_FEATURE_webengine_webrtc_pipewire 1
 
-#define QT_FEATURE_webengine_full_debug_info -1
+#define QT_FEATURE_webengine_full_debug_info 1
 
 #define QT_FEATURE_webengine_sanitizer -1
 
